SearchBarConfig<T> class

==================== SEARCH BAR CONFIG ====================

Constructors

SearchBarConfig({required String url, required T fromJson(Map<String, dynamic>), required Widget itemBuilder(T), required String searchBy(T), double searchItemHeight = 300.0, double searchErrorHeight = 100, Color searchCursorColor = Colors.white38, Color? searchBackgroundColor})

Properties

fromJson → T Function(Map<String, dynamic>)
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(T)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBackgroundColor Color?
final
searchBy String Function(T)
final
searchCursorColor Color
final
searchErrorHeight double
final
searchItemHeight double
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited