DrawerItem class


Drawer item

Constructors

DrawerItem({required IconData icon, required String title, required VoidCallback onTap, String? subtitle, Color? iconColor, Color? itemBackgroundColor, EdgeInsetsGeometry? margin, BorderRadius? borderRadius, TextStyle? titleStyle, TextStyle? subtitleStyle, Widget customBuilder(BuildContext context)?})
const

Properties

borderRadius BorderRadius?
final
customBuilder Widget Function(BuildContext context)?
Optional fully custom widget for this item
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
iconColor Color?
final
itemBackgroundColor Color?
final
margin EdgeInsetsGeometry?
final
onTap VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
subtitleStyle TextStyle?
final
title String
final
titleStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited