ImageWidget class

Reusable Image Widget with placeholder animations

Inheritance

Constructors

ImageWidget({Key? key, required String path, ImageSourceType sourceType = ImageSourceType.network, double width = double.infinity, double height = 200, BoxFit fit = BoxFit.cover, double borderRadius = 14, Color? backgroundColor, Widget? errorWidget, bool isShimmer = false, SpinKitAnimationType spinKitType = SpinKitAnimationType.doubleBounce, Color? placeholderColor, double placeholderSize = 40, VoidCallback? onSuccess, void onError(Object error, StackTrace? stackTrace)?})
const

Properties

backgroundColor Color?
final
borderRadius double
final
errorWidget Widget?
Shown ONLY if provided and the image fails to load. If null, nothing is shown on failure (empty box).
final
fit BoxFit
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
isShimmer bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError → void Function(Object error, StackTrace? stackTrace)?
Called once when the image fails to load. Provides the error and stack trace for logging purposes.
final
onSuccess VoidCallback?
Called once when the image finishes loading successfully.
final
path String
final
placeholderColor Color?
final
placeholderSize double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceType ImageSourceType
final
spinKitType SpinKitAnimationType
final
width double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ImageWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited