errorWidget property
Shown ONLY if provided and the image fails to load. If null, nothing is shown on failure (empty box).
Implementation
final Widget? errorWidget;
Shown ONLY if provided and the image fails to load. If null, nothing is shown on failure (empty box).
final Widget? errorWidget;