onError property
Called once when the image fails to load. Provides the error and stack trace for logging purposes.
Implementation
final void Function(Object error, StackTrace? stackTrace)? onError;
Called once when the image fails to load. Provides the error and stack trace for logging purposes.
final void Function(Object error, StackTrace? stackTrace)? onError;