SpinKitAnimationType enum

All supported SpinKit animation types

Inheritance
Available extensions

Values

rotatingPlain → const SpinKitAnimationType
doubleBounce → const SpinKitAnimationType
wave → const SpinKitAnimationType
wanderingCubes → const SpinKitAnimationType
fadingFour → const SpinKitAnimationType
fadingCube → const SpinKitAnimationType
pulse → const SpinKitAnimationType
chasingDots → const SpinKitAnimationType
threeBounce → const SpinKitAnimationType
circle → const SpinKitAnimationType
cubeGrid → const SpinKitAnimationType
fadingCircle → const SpinKitAnimationType
rotatingCircle → const SpinKitAnimationType
foldingCube → const SpinKitAnimationType
pumpingHeart → const SpinKitAnimationType
hourGlass → const SpinKitAnimationType
pouringHourGlass → const SpinKitAnimationType
pouringHourGlassRefined → const SpinKitAnimationType
fadingGrid → const SpinKitAnimationType
ring → const SpinKitAnimationType
ripple → const SpinKitAnimationType
spinningCircle → const SpinKitAnimationType
spinningLines → const SpinKitAnimationType
squareCircle → const SpinKitAnimationType
dualRing → const SpinKitAnimationType
pianoWave → const SpinKitAnimationType
dancingSquare → const SpinKitAnimationType
threeInOut → const SpinKitAnimationType
waveSpinner → const SpinKitAnimationType
pulsingGrid → const SpinKitAnimationType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SpinKitAnimationType>
A constant List of the values in this enum, in order of their declaration.