RadioGroupWidget<T> class

Inheritance

Constructors

RadioGroupWidget({Key? key, required List<T> items, ValueChanged<T>? onChanged, String? title, String? subtitle, TextStyle? titleStyle, TextStyle? subtitleStyle, Color? selectedTitleColor, Color? unselectedTitleColor, Color? selectedSubtitleColor, Color? unselectedSubtitleColor, IconData selectedRadioIcon = Icons.radio_button_checked, IconData unselectedRadioIcon = Icons.radio_button_unchecked, Color? selectedRadioIconColor, Color? unselectedRadioIconColor, double radioIconSize = 24, IconData? selectedTrailingIcon = Icons.arrow_forward_ios, IconData? unselectedTrailingIcon = Icons.arrow_forward_ios, Color? selectedTrailingColor = Colors.white, Color? unselectedTrailingColor, double trailingIconSize = 18, Color? unSelectedBackgroundColo = Colors.white, Color? selectedunSelectedBackgroundColo = Colors.blue, double borderRadius = 12, double borderWidth = 1, Color? borderColor = Colors.transparent, Color? shadowColor, int initialIndex = 0, double dividerHeight = 12})
Example Usage
const

Properties

borderColor Color?
final
borderRadius double
final
borderWidth double
final
dividerHeight double
final
hashCode int
The hash code for this object.
no setterinherited
initialIndex int
final
items List<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ValueChanged<T>?
final
radioIconSize double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedRadioIcon IconData
final
selectedRadioIconColor Color?
final
selectedSubtitleColor Color?
final
selectedTitleColor Color?
final
selectedTrailingColor Color?
final
selectedTrailingIcon IconData?
final
selectedunSelectedBackgroundColo Color?
final
shadowColor Color?
final
subtitle String?
final
subtitleStyle TextStyle?
final
title String?
final
titleStyle TextStyle?
final
trailingIconSize double
final
unSelectedBackgroundColo Color?
final
unselectedRadioIcon IconData
final
unselectedRadioIconColor Color?
final
unselectedSubtitleColor Color?
final
unselectedTitleColor Color?
final
unselectedTrailingColor Color?
final
unselectedTrailingIcon IconData?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RadioGroupWidget<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited