SwitchItem class

🔹 Switch Item

Constructors

SwitchItem({required String label, IconData? icon, String? assetIcon, double? iconSize, double? selectedIconSize, double? assetIconSize, int? badge, double? badgeSize, Color? badgeColor, Widget page = const SizedBox(), double? badgePositionRight, Color? badgeCountsColor, double? badgeCountsSize, double? badgePositionTop})
const

Properties

assetIcon → String?
final
assetIconSize → double?
final
badge → int?
final
badgeColor → Color?
final
badgeCountsColor → Color?
final
badgeCountsSize → double?
final
badgePositionRight → double?
final
badgePositionTop → double?
final
badgeSize → double?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
iconSize → double?
final
label → String
final
page → Widget
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIconSize → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited