TabBarWidget<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TabBarWidget
- Implemented types
Constructors
-
TabBarWidget({Key? key, required List<
T> tabs, required ValueChanged<int> onTabChanged, required String labelBuilder(T item), Widget tabBuilder(T item, bool isSelected)?, int initialIndex = 0, double height = 56, double borderRadius = 14, Color? selectedColor, Color? unselectedColor, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 20, vertical: 12), EdgeInsetsGeometry margin = const EdgeInsets.only(right: 20), double itemSpacing = 5}) -
const
Properties
- borderRadius → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- initialIndex → int
-
final
- itemSpacing → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelBuilder → String Function(T item)
-
How to display each tab (required)
final
- margin → EdgeInsetsGeometry
-
final
-
onTabChanged
→ ValueChanged<
int> -
final
- padding → EdgeInsetsGeometry
-
final
- preferredSize → Size
-
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color?
-
final
- tabBuilder → Widget Function(T item, bool isSelected)?
-
Optional custom tab widget
final
-
tabs
→ List<
T> -
final
- unselectedColor → Color?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TabBarWidget< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited