AppListView<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AppListView
Constructors
-
AppListView({Key? key, required List<
T> items, ValueChanged<T> ? onTap, bool isSelectable = false, T? selectedItem, Color? selectedColor = Colors.blue, Color? unselectedColor = Colors.white, double? borderRadius = 12, double? borderWidth, Color? borderColor, EdgeInsets padding = const EdgeInsets.all(12), Color? backgroundColor = Colors.white, String titleBuilder(T)?, String subtitleBuilder(T)?, IconData leadingIconBuilder(T)?, IconData trailingIconBuilder(T)?, double? titleSize, double? subtitleSize, double iconSize = 24, double? dividerHeight, Color? titleColor, Color? subtitleColor, Color? leadingIconColor, Color? trailingIconColor, TextStyle? titleStyle, TextStyle? subtitleStyle, TextStyle? selectedTitleStyle = const TextStyle(color: Colors.white), TextStyle? unselectedTitleStyle, TextStyle? selectedSubtitleStyle = const TextStyle(color: Colors.white), TextStyle? unselectedSubtitleStyle, IconThemeData? selectedLeadingIconStyle = const IconThemeData(color: Colors.white), IconThemeData? unselectedLeadingIconStyle, IconThemeData? selectedTrailingIconStyle = const IconThemeData(color: Colors.white), IconThemeData? unselectedTrailingIconStyle, bool isSearchable = false, String searchHint = 'Search items...', TextStyle? searchHintStyle, IconData? searchLeadingIcon = Icons.search, IconData? searchTrailingIcon = Icons.clear, double searchHeight = 56, double? searchBorderRadius = 12, Color? searchFillColor = Colors.white, Color? searchFillActiveColor = const Color(0xFFF2F2F2), Color? searchBorderColor = Colors.grey, double searchBorderWidth = 1, IconThemeData? searchLeadingIconStyle = const IconThemeData(color: Colors.grey), IconThemeData? searchTrailingIconStyle = const IconThemeData(color: Colors.grey), ValueChanged<String> ? onSearchChanged, bool isShowTitle = true, String? listTitle = "Items", TextStyle? listTitleStyle, IconData listFilterIcon = Icons.filter_list, IconThemeData? listFilterIconStyle, bool isShowFilter = true, List<String> filterNames = const ['New', 'Old'], ValueChanged<String> ? onFilterSelected, Widget? noResultsWidget, EdgeInsetsGeometry? searchPadding}) -
const
Properties
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderRadius → double?
-
final
- borderWidth → double?
-
final
- dividerHeight → double?
-
final
-
filterNames
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize → double
-
final
- isSearchable → bool
-
final
- isSelectable → bool
-
final
- isShowFilter → bool
-
final
- isShowTitle → bool
-
final
-
items
→ List<
T> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leadingIconBuilder → IconData Function(T)?
-
final
- leadingIconColor → Color?
-
final
- listFilterIcon → IconData
-
final
- listFilterIconStyle → IconThemeData?
-
final
- listTitle → String?
-
final
- listTitleStyle → TextStyle?
-
final
- noResultsWidget → Widget?
-
final
-
onFilterSelected
→ ValueChanged<
String> ? -
final
-
onSearchChanged
→ ValueChanged<
String> ? -
final
-
onTap
→ ValueChanged<
T> ? -
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchBorderColor → Color?
-
final
- searchBorderRadius → double?
-
final
- searchBorderWidth → double
-
final
- searchFillActiveColor → Color?
-
final
- searchFillColor → Color?
-
final
- searchHeight → double
-
final
- searchHint → String
-
final
- searchHintStyle → TextStyle?
-
final
- searchLeadingIcon → IconData?
-
final
- searchLeadingIconStyle → IconThemeData?
-
final
- searchPadding → EdgeInsetsGeometry?
-
final
- searchTrailingIcon → IconData?
-
final
- searchTrailingIconStyle → IconThemeData?
-
final
- selectedColor → Color?
-
final
- selectedItem → T?
-
final
- selectedLeadingIconStyle → IconThemeData?
-
final
- selectedSubtitleStyle → TextStyle?
-
final
- selectedTitleStyle → TextStyle?
-
final
- selectedTrailingIconStyle → IconThemeData?
-
final
- subtitleBuilder → String Function(T)?
-
final
- subtitleColor → Color?
-
final
- subtitleSize → double?
-
final
- subtitleStyle → TextStyle?
-
final
- titleBuilder → String Function(T)?
-
final
- titleColor → Color?
-
final
- titleSize → double?
-
final
- titleStyle → TextStyle?
-
final
- trailingIconBuilder → IconData Function(T)?
-
final
- trailingIconColor → Color?
-
final
- unselectedColor → Color?
-
final
- unselectedLeadingIconStyle → IconThemeData?
-
final
- unselectedSubtitleStyle → TextStyle?
-
final
- unselectedTitleStyle → TextStyle?
-
final
- unselectedTrailingIconStyle → IconThemeData?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AppListView< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited