ChipWidget<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ChipWidget
Constructors
-
ChipWidget({Key? key, required List<
T> values, required void onSelected(T value, int index), String labelBuilder(T value)?, WrapAlignment alignment = WrapAlignment.start, bool isEnabledRadioBtn = true, int initialIndex = 0, IconData selectedRadioIcon = Icons.check_circle, IconData? unselectedRadioIcon = Icons.radio_button_off, Color? selectedRadioIconColor, Color? unselectedRadioIconColor = Colors.black26, double radioIconSize = 18, Color? selectedColor, Color? unselectedColor, TextStyle? selectedTextStyle, TextStyle? unselectedTextStyle, double borderRadius = 20, Color borderColor = Colors.transparent, double borderWidth = 0, double chipHeight = 40, double? chipWidth, Duration animationDuration = const Duration(milliseconds: 250), Curve animationCurve = Curves.easeOut, bool enableTapEffect = true, double tapScale = 0.94, Duration tapDuration = const Duration(milliseconds: 120)}) -
const
Properties
- alignment → WrapAlignment
-
Overall chips alignment
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- borderColor → Color
-
final
- borderRadius → double
-
final
- borderWidth → double
-
final
- chipHeight → double
-
final
- chipWidth → double?
-
final
- enableTapEffect → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialIndex → int
-
final
- isEnabledRadioBtn → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelBuilder → String Function(T value)?
-
final
- onSelected → void Function(T value, int index)
-
final
- radioIconSize → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color?
-
final
- selectedRadioIcon → IconData
-
final
- selectedRadioIconColor → Color?
-
final
- selectedTextStyle → TextStyle?
-
final
- tapDuration → Duration
-
final
- tapScale → double
-
final
- unselectedColor → Color?
-
final
- unselectedRadioIcon → IconData?
-
final
- unselectedRadioIconColor → Color?
-
final
- unselectedTextStyle → TextStyle?
-
final
-
values
→ List<
T> -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ChipWidget< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited