PatternBackground class
A widget that draws a background pattern behind any child.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PatternBackground
Constructors
- PatternBackground({Key? key, required Widget child, Color patternColor = const Color(0x20FFFFFF), double patternSize = 4.0, double patternSpacing = 20.0, PatternType patternType = PatternType.dot, Color backgroundColor = Colors.transparent})
-
const
Properties
- backgroundColor → Color
-
Background color behind pattern
final
- child → Widget
-
The child widget to render on top of the pattern
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- patternColor → Color
-
Color of the pattern
final
- patternSize → double
-
Size of each pattern element (dot, square, etc.)
final
- patternSpacing → double
-
Spacing between pattern elements
final
- patternType → PatternType
-
Type of pattern: dot or line
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited